"""
Module load handler for execution via:

python -m mistymountain
"""
from __future__ import absolute_import, division, print_function, unicode_literals


def main():
    """
    Test
    """
    print(
        """\
For more information view the online documentation at:
https://mistymountain.readthedocs.io/en/latest/
"""
    )


if __name__ == "__main__":
    main()
